@@ -6,17 +6,14 @@ provided by `FileSystemCommands` class.  See `SubversionCommands` and
 `MercurialCommands` for example.
 
 """
-import re
+
 import os
+import re
 import shutil
 import subprocess
+import typing
 
-import rope.base.utils.pycompat as pycompat
-
-try:
-    unicode
-except NameError:
-    unicode = str
+FileContent = typing.NewType("FileContent", bytes)
 
 
 def create_fscommands(root):
@@ -68,7 +65,7 @@ class FileSystemCommands:
 class SubversionCommands:
     def __init__(self, *args):
         self.normal_actions = FileSystemCommands()
-        import pysvn
+        import pysvn  # type:ignore
 
         self.client = pysvn.Client()
 
@@ -106,7 +103,7 @@ class MercurialCommands:
                 traceback=False,
                 report_untrusted=False,
             )
-        except:
+        except Exception:
             self.ui = self.hg.ui.ui()
             self.ui.setconfig("ui", "interactive", "no")
             self.ui.setconfig("ui", "debug", "no")
@@ -118,9 +115,9 @@ class MercurialCommands:
         self.repo = self.hg.hg.repository(self.ui, root)
 
     def _import_mercurial(self):
-        import mercurial.commands
-        import mercurial.hg
-        import mercurial.ui
+        import mercurial.commands  # type:ignore
+        import mercurial.hg  # type:ignore
+        import mercurial.ui  # type:ignore
 
         return mercurial
 
@@ -214,19 +211,18 @@ def _execute(args, cwd=None):
     return process.returncode
 
 
-def unicode_to_file_data(contents, encoding=None, newlines=None):
-    if not isinstance(contents, unicode):
-        return contents
+def unicode_to_file_data(contents: str, encoding=None, newlines=None) -> FileContent:
+    assert isinstance(contents, str)
     if newlines and newlines != "\n":
         contents = contents.replace("\n", newlines)
     if encoding is None:
         encoding = read_str_coding(contents)
     if encoding is not None:
-        return contents.encode(encoding)
+        return FileContent(contents.encode(encoding))
     try:
-        return contents.encode()
+        return FileContent(contents.encode())
     except UnicodeEncodeError:
-        return contents.encode("utf-8")
+        return FileContent(contents.encode("utf-8"))
 
 
 def file_data_to_unicode(data, encoding=None):
@@ -242,7 +238,7 @@ def file_data_to_unicode(data, encoding=None):
 
 
 def _decode_data(data, encoding):
-    if isinstance(data, unicode):
+    if isinstance(data, str):
         return data
     if encoding is None:
         encoding = read_str_coding(data)
