@@ -1,15 +1,9 @@
+import unittest
 from textwrap import dedent
 
-from rope.base.builtins import Str
-
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
-
 import rope.base.libutils
 import rope.base.oi
-from rope.base.utils import pycompat
+from rope.base.builtins import Str
 from ropetest import testutils
 
 
@@ -1055,7 +1049,7 @@ class NewStaticOITest(unittest.TestCase):
             l = {}
             v = l["key"]
         """))
-        pymod1 = self.project.get_pymodule(mod1)  # noqa
+        pymod1 = self.project.get_pymodule(mod1)
         var = pymod1["v"].get_object()  # noqa
 
     def test_always_returning_containing_class_for_selfs(self):
